### Name: crossProdLasso
### Title: Performs the lasso on the cross product matrices $X'X$ and $X'y$
### Aliases: crossProdLasso


### ** Examples

data(diabetes)
attach(diabetes)
# First, let's do scout(2,1) the usual way).
scout.out <- scout(x2,y,p1=2,p2=1)
print(scout.out)


# Now, suppose I want to do develop a covariance-regularized regression
# method as in Section 3.2 of Witten and Tibshirani (2008). It will work
# like this:
# 1. Estimate $\Sigma$ by hard-thresholding $X'X$
# 2. Find $\beta$ by minimize $\beta^T \Sigma \beta - 2 \beta^T X^T y +
# \lamda ||\beta||_1$
# 3. Re-scale $\beta$.

# Step 1:
regcovx <- cov(x2)*(abs(cov(x2))>.05)
# Step 2:
betahat <-  crossProdLasso(regcovx, cov(x2,y), rho=.02)$beta
# Step 3:
betahat.sc <- betahat*lsfit(x2%*%betahat, y, intercept=FALSE)$coef
print(betahat.sc)

# Try a different value of rho:
betahat2 <- crossProdLasso(regcovx,cov(x2,y),rho=.04,beta.init=betahat)$beta
plot(betahat,betahat2, xlab="rho=.02",ylab="rho=.04")
detach(diabetes)



